@@ -8,7 +8,9 @@ use warnings;
 use Carp;
 use base qw{ Exporter };
 
-our $VERSION = '0.015';
+our $VERSION = '0.023';
+
+no warnings qw{ once };	# For older Perls.
 
 our @CARP_NOT = qw{
     PPIx::QuoteLike
@@ -25,6 +27,8 @@ our @CARP_NOT = qw{
     PPIx::QuoteLike::Utils
 };
 
+use warnings qw{ once };
+
 our @EXPORT_OK = qw{
     ARRAY_REF
     MINIMUM_PERL
@@ -51,12 +55,15 @@ use constant HAVE_PPIX_REGEXP	=> do {
     };
 };
 
-# Location constants. Must align with PPI
+# The '## VERBATIM' annotations support test xt/author/verbatim.t
+## VERBATIM EXPECT 1
+## VERBATIM BEGIN PPI::Document
 use constant LOCATION_LINE         => 0;
 use constant LOCATION_CHARACTER    => 1;
 use constant LOCATION_COLUMN       => 2;
 use constant LOCATION_LOGICAL_LINE => 3;
 use constant LOCATION_LOGICAL_FILE => 4;
+## VERBATIM END
 
 use constant MINIMUM_PERL	=> '5.000';
 
@@ -132,6 +139,7 @@ names, without the leading sigil. Nothing is captured.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=PPIx-QuoteLike>,
 L<https://github.com/trwyant/perl-PPIx-QuoteLike/issues>, or in
 electronic mail to the author.
 
@@ -141,7 +149,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2016-2021 by Thomas R. Wyant, III
+Copyright (C) 2016-2022 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
