@@ -20,7 +20,7 @@ use PPIx::QuoteLike::Utils qw{
 
 use base qw{ PPIx::QuoteLike::Token };
 
-our $VERSION = '0.017';
+our $VERSION = '0.023';
 
 sub ppi {
     my ( $self ) = @_;
@@ -76,7 +76,7 @@ sub variables {
 
 sub __perl_version_introduced {
     my ( $self ) = @_;
-    $self->content() =~ m/ -> (?: \@ [[{*] | % [*] ) /smx
+    $self->{postderef}
 	and return '5.019005';
     return;
 }
@@ -131,16 +131,18 @@ C<'${foo}'>, but the content of the C<PPI::Document> will be C<'$foo'>.
 
  say "Interpolates $_" for $elem->variables();
 
-This convenience method returns all interpolated variables. Each is
-returned only once, and they are returned in no particular order.
-
 B<NOTE> that this method is discouraged, and may well be deprecated and
-removed. My problem with it is that it returns variable names rather
-than L<PPI::Element|PPI::Element> objects, leaving you no idea how the
-variables are used. It was originally written for the benefit of
+removed. I have two problems with it. The first is that it returns
+variable names rather than L<PPI::Element|PPI::Element> objects, leaving
+you no idea how the variables are used. The second is that it does not
+properly handle things like C<"${^CAPTURE[0]}">, and it seems infeasible
+to make it do so. It was originally written for the benefit of
 L<Perl::Critic::Policy::Variables::ProhibitUnusedVarsStricter|Perl::Critic::Policy::Variables::ProhibitUnusedVarsStricter>,
 but has proven inadequate to that policy's needs.
 
+This convenience method returns all interpolated variables. Each is
+returned only once, and they are returned in no particular order.
+
 =head1 SEE ALSO
 
 L<PPIx::QuoteLike::Token|PPIx::QuoteLike::Token>.
@@ -158,7 +160,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2016-2021 by Thomas R. Wyant, III
+Copyright (C) 2016-2022 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
